==> clickhouse_1.1.54387.tar.xz: clickhouse-1.1.54387/docs/ru/interfaces/third-party_client_libraries.md <==
# Библиотеки от сторонних разработчиков

Мы не тестировали перечисленные ниже библиотеки.

- Python:
    - [infi.clickhouse_orm](https://github.com/Infinidat/infi.clickhouse_orm)
    - [sqlalchemy-clickhouse](https://github.com/cloudflare/sqlalchemy-clickhouse)
    - [clickhouse-driver](https://github.com/mymarilyn/clickhouse-driver)
    - [clickhouse-client](https://github.com/yurial/clickhouse-client)
- PHP
    - [clickhouse-php-client](https://github.com/8bitov/clickhouse-php-client)
    - [PhpClickHouseClient](https://github.com/SevaCode/PhpClickHouseClient)
    - [phpClickHouse](https://github.com/smi2/phpClickHouse)
    - [clickhouse-client](https://github.com/bozerkins/clickhouse-client)
- Go
    - [clickhouse](https://github.com/kshvakov/clickhouse/)
    - [go-clickhouse](https://github.com/roistat/go-clickhouse)
    - [mailrugo-clickhouse](https://github.com/mailru/go-clickhouse)
    - [golang-clickhouse](https://github.com/leprosus/golang-clickhouse)
- NodeJs
    - [clickhouse (NodeJs)](https://github.com/TimonKK/clickhouse)
    - [node-clickhouse](https://github.com/apla/node-clickhouse)
- Perl
    - [perl-DBD-ClickHouse](https://github.com/elcamlost/perl-DBD-ClickHouse)
    - [HTTP-ClickHouse](https://metacpan.org/release/HTTP-ClickHouse)
    - [AnyEvent-ClickHouse](https://metacpan.org/release/AnyEvent-ClickHouse)
- Ruby
    - [clickhouse (Ruby)](https://github.com/archan937/clickhouse)
- R
    - [clickhouse-r](https://github.com/hannesmuehleisen/clickhouse-r)
    - [RClickhouse](https://github.com/IMSMWU/RClickhouse)
- .NET
    - [ClickHouse-Net](https://github.com/killwort/ClickHouse-Net)
- C++
    - [clickhouse-cpp](https://github.com/artpaul/clickhouse-cpp/)
- Elixir
    - [clickhousex](https://github.com/appodeal/clickhousex/)
    - [clickhouse_ecto](https://github.com/appodeal/clickhouse_ecto)
- Java
    - [clickhouse-client-java](https://github.com/VirtusAI/clickhouse-client-java)
- Nim
    - [nim-clickhouse](https://github.com/leonardoce/nim-clickhouse)

==> clickhouse_18.2.0.tar.xz: clickhouse-18.2.0/docs/ru/interfaces/third-party_client_libraries.md <==
# Библиотеки от сторонних разработчиков

Мы не тестировали перечисленные ниже библиотеки.

- Python:
    - [infi.clickhouse_orm](https://github.com/Infinidat/infi.clickhouse_orm)
    - [sqlalchemy-clickhouse](https://github.com/cloudflare/sqlalchemy-clickhouse)
    - [clickhouse-driver](https://github.com/mymarilyn/clickhouse-driver)
    - [clickhouse-client](https://github.com/yurial/clickhouse-client)
- PHP
    - [phpClickHouse](https://github.com/smi2/phpClickHouse)
    - [clickhouse-php-client](https://github.com/8bitov/clickhouse-php-client)
    - [clickhouse-client](https://github.com/bozerkins/clickhouse-client)
    - [PhpClickHouseClient](https://github.com/SevaCode/PhpClickHouseClient)
- Go
    - [clickhouse](https://github.com/kshvakov/clickhouse/)
    - [go-clickhouse](https://github.com/roistat/go-clickhouse)
    - [mailrugo-clickhouse](https://github.com/mailru/go-clickhouse)
    - [golang-clickhouse](https://github.com/leprosus/golang-clickhouse)
- NodeJs
    - [clickhouse (NodeJs)](https://github.com/TimonKK/clickhouse)
    - [node-clickhouse](https://github.com/apla/node-clickhouse)
- Perl
    - [perl-DBD-ClickHouse](https://github.com/elcamlost/perl-DBD-ClickHouse)
    - [HTTP-ClickHouse](https://metacpan.org/release/HTTP-ClickHouse)
    - [AnyEvent-ClickHouse](https://metacpan.org/release/AnyEvent-ClickHouse)
- Ruby
    - [clickhouse (Ruby)](https://github.com/archan937/clickhouse)
- R
    - [clickhouse-r](https://github.com/hannesmuehleisen/clickhouse-r)
    - [RClickhouse](https://github.com/IMSMWU/RClickhouse)
- .NET
    - [ClickHouse.Ado](https://github.com/killwort/ClickHouse-Net)
    - [ClickHouse.Net](https://github.com/ilyabreev/ClickHouse.Net)
    - [ClickHouse.Net.Migrations](https://github.com/ilyabreev/ClickHouse.Net.Migrations)
- C++
    - [clickhouse-cpp](https://github.com/artpaul/clickhouse-cpp/)
- Elixir
    - [clickhousex](https://github.com/appodeal/clickhousex/)
    - [clickhouse_ecto](https://github.com/appodeal/clickhouse_ecto)
- Java
    - [clickhouse-client-java](https://github.com/VirtusAI/clickhouse-client-java)
- Nim
    - [nim-clickhouse](https://github.com/leonardoce/nim-clickhouse)
